@@ -42,6 +42,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <unistd.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdbool.h>
 
 /* We shall not export the log_msg() sumbol */
 #undef PCSC_API
@@ -68,11 +69,7 @@ static void log_init(void)
 {
 	char *e;
 
-#ifdef LIBPCSCLITE
 	e = getenv("PCSCLITE_DEBUG");
-#else
-	e = getenv("MUSCLECARD_DEBUG");
-#endif
 	if (e)
 		LogLevel = atoi(e);
 
@@ -105,12 +102,12 @@ void log_msg(const int priority, const char *fmt, ...)
 {
 	char DebugBuffer[DEBUG_BUF_SIZE];
 	va_list argptr;
-	static int is_initialized = 0;
+	static bool is_initialized = false;
 
 	if (!is_initialized)
 	{
 		log_init();
-		is_initialized = 1;
+		is_initialized = true;
 	}
 
 	if (priority < LogLevel) /* log priority lower than threshold? */
