@@ -54,10 +54,10 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 		char readerName[MAX_READERNAME]; /**< reader name */
 		uint32_t eventCounter; /**< number of card events */
 		uint32_t readerState; /**< SCARD_* bit field */
-		int32_t readerSharing; /**< PCSCLITE_SHARING_* sharing status */
+		_Atomic int32_t readerSharing; /**< PCSCLITE_SHARING_* sharing status */
 
 		UCHAR cardAtr[MAX_ATR_SIZE]; /**< ATR */
-		uint32_t cardAtrLength; /**< ATR length */
+		_Atomic uint32_t cardAtrLength; /**< ATR length */
 		uint32_t cardProtocol; /**< SCARD_PROTOCOL_* value */
 	}
 	READER_STATE;
