@@ -55,6 +55,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <libusb.h>
 #include <pthread.h>
 #include <signal.h>
+#include <stdbool.h>
 
 #include "misc.h"
 #include "wintypes.h"
@@ -76,11 +77,8 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define READER_PRESENT		1
 #define READER_FAILED		2
 
-#define FALSE			0
-#define TRUE			1
-
-extern char Add_Interface_In_Name;
-extern char Add_Serial_In_Name;
+extern bool Add_Interface_In_Name;
+extern bool Add_Serial_In_Name;
 
 /* we use the default libusb context */
 #define ctx NULL
@@ -89,7 +87,7 @@ pthread_mutex_t usbNotifierMutex;
 
 static pthread_t usbNotifyThread;
 static int driverSize = -1;
-static char AraKiriHotPlug = FALSE;
+static bool AraKiriHotPlug = false;
 static int rescan_pipe[] = { -1, -1 };
 extern int HPForceReaderPolling;
 
@@ -131,7 +129,7 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 static LONG HPRemoveHotPluggable(int reader_index);
 static void HPCleanupHotPluggable(int reader_index);
 
-static LONG HPReadBundleValues(void)
+static LONG HPReadBundleValues(const char * hpDirPath)
 {
 	LONG rv;
 	DIR *hpDir;
@@ -140,11 +138,12 @@ static LONG HPReadBundleValues(void)
 	char fullLibPath[FILENAME_MAX];
 	int listCount = 0;
 
-	hpDir = opendir(PCSCLITE_HP_DROPDIR);
+	hpDir = opendir(hpDirPath);
 
 	if (hpDir == NULL)
 	{
-		Log1(PCSC_LOG_ERROR, "Cannot open PC/SC drivers directory: " PCSCLITE_HP_DROPDIR);
+		Log2(PCSC_LOG_ERROR, "Cannot open PC/SC drivers directory: %s",
+			hpDirPath);
 		Log1(PCSC_LOG_ERROR, "Disabling USB support for pcscd.");
 		return -1;
 	}
@@ -183,7 +182,7 @@ static LONG HPReadBundleValues(void)
 			 * vendor and product ID's for this particular bundle
 			 */
 			snprintf(fullPath, sizeof(fullPath), "%s/%s/Contents/Info.plist",
-				PCSCLITE_HP_DROPDIR, currFP->d_name);
+				hpDirPath, currFP->d_name);
 			fullPath[sizeof(fullPath) - 1] = '\0';
 
 			rv = bundleParse(fullPath, &plist);
@@ -195,7 +194,7 @@ static LONG HPReadBundleValues(void)
 			libraryPath = list_get_at(values, 0);
 			(void)snprintf(fullLibPath, sizeof(fullLibPath),
 				"%s/%s/Contents/%s/%s",
-				PCSCLITE_HP_DROPDIR, currFP->d_name, PCSC_ARCH,
+				hpDirPath, currFP->d_name, PCSC_ARCH,
 				libraryPath);
 			fullLibPath[sizeof(fullLibPath) - 1] = '\0';
 
@@ -285,7 +284,8 @@ static LONG HPReadBundleValues(void)
 
 	if (driverSize == 0)
 	{
-		Log1(PCSC_LOG_INFO, "No bundle files in pcsc drivers directory: " PCSCLITE_HP_DROPDIR);
+		Log2(PCSC_LOG_INFO, "No bundle files in pcsc drivers directory: %s",
+			hpDirPath);
 		Log1(PCSC_LOG_INFO, "Disabling USB support for pcscd");
 	}
 #ifdef DEBUG_HOTPLUG
@@ -401,13 +401,13 @@ static void HPRescanUsbBus(void)
 		for (interface = 0; interface < config_desc->bNumInterfaces;
 				interface++)
 		{
-			int newreader;
+			bool newreader;
 
 			/* A known device has been found */
 			snprintf(bus_device, BUS_DEVICE_STRSIZE, "%d:%d:%d",
 					bus_number, device_address, interface);
 			bus_device[BUS_DEVICE_STRSIZE - 1] = '\0';
-			newreader = TRUE;
+			newreader = true;
 
 			/* Check if the reader is a new one */
 			for (j=0; j<PCSCLITE_MAX_READERS_CONTEXTS; j++)
@@ -417,7 +417,7 @@ static void HPRescanUsbBus(void)
 				{
 					/* The reader is already known */
 					readerTracker[j].status = READER_PRESENT;
-					newreader = FALSE;
+					newreader = false;
 #ifdef DEBUG_HOTPLUG
 					Log2(PCSC_LOG_DEBUG, "Refresh USB device: %s",
 							bus_device);
@@ -475,7 +475,7 @@ static void HPRescanUsbBus(void)
 
 static void * HPEstablishUSBNotifications(int pipefd[2])
 {
-	int i, do_polling;
+	bool do_polling;
 	int r;
 	char c = 42;	/* magic value */
 
@@ -499,8 +499,8 @@ static void * HPEstablishUSBNotifications(int pipefd[2])
 	}
 
 	/* if at least one driver do not have IFD_GENERATE_HOTPLUG */
-	do_polling = FALSE;
-	for (i=0; i<driverSize; i++)
+	do_polling = false;
+	for (int i=0; i<driverSize; i++)
 		if (driverTracker[i].libraryPath)
 			if ((driverTracker[i].ifdCapabilities & IFD_GENERATE_HOTPLUG) == 0)
 			{
@@ -516,7 +516,7 @@ static void * HPEstablishUSBNotifications(int pipefd[2])
 	{
 		Log2(PCSC_LOG_INFO,
 				"Polling forced every %d second(s)", HPForceReaderPolling);
-		do_polling = TRUE;
+		do_polling = true;
 	}
 
 	if (do_polling)
@@ -553,11 +553,11 @@ static void * HPEstablishUSBNotifications(int pipefd[2])
 	return NULL;
 }
 
-LONG HPSearchHotPluggables(void)
+LONG HPSearchHotPluggables(const char * hpDirPath)
 {
 	int i;
 
-	AraKiriHotPlug = FALSE;
+	AraKiriHotPlug = false;
 	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
 		readerTracker[i].status = READER_ABSENT;
@@ -565,7 +565,7 @@ LONG HPSearchHotPluggables(void)
 		readerTracker[i].fullName = NULL;
 	}
 
-	if (HPReadBundleValues() > 0)
+	if (HPReadBundleValues(hpDirPath) > 0)
 	{
 		int pipefd[2];
 		char c;
@@ -596,7 +596,7 @@ LONG HPSearchHotPluggables(void)
 
 LONG HPStopHotPluggables(void)
 {
-	AraKiriHotPlug = TRUE;
+	AraKiriHotPlug = true;
 	if (rescan_pipe[1] >= 0)
 	{
 		close(rescan_pipe[1]);
@@ -796,8 +796,10 @@ static void HPCleanupHotPluggable(int reader_index)
 /**
  * Sets up callbacks for device hotplug events.
  */
-ULONG HPRegisterForHotplugEvents(void)
+ULONG HPRegisterForHotplugEvents(const char * hpDirPath)
 {
+	(void)hpDirPath;
+
 	(void)pthread_mutex_init(&usbNotifierMutex, NULL);
 	return 0;
 }
